@@ -494,7 +494,7 @@ def make_window():
               [options_at_bottom]]
 
     # --------------------------------- Create Window ---------------------------------
-    window = sg.Window('PSG Demo & Project Browser', layout, finalize=True,  resizable=True, use_default_focus=False)
+    window = sg.Window('PSG Demo & Project Browser', layout, finalize=True,  resizable=True, use_default_focus=False, right_click_menu=sg.MENU_RIGHT_CLICK_EDITME_VER_EXIT)
     window.set_min_size(window.size)
 
     window['-DEMO LIST-'].expand(True, True, True)
@@ -715,7 +715,8 @@ def main():
                 if line is not None:
                     sg.cprint(f'Added to Clipboard Full Path {full_filename}', c='white on purple')
                     sg.clipboard_set(full_filename)
-
+        elif event == 'Version':
+            sg.popup_scrolled(sg.get_versions(), keep_on_top=True, non_blocking=True)
     window.close()
 
 
